# @turf/helpers

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

## helpers

### earthRadius

The Earth radius in kilometers. Used by Turf modules that model the Earth as a sphere. The [mean radius][1] was selected because it is [recommended ][2] by the Haversine formula (used by turf/distance) to reduce error.

Type: [number][3]

### factors

Unit of measurement factors based on earthRadius.

Keys are the name of the unit, values are the number of that unit in a single radian

Type: [Object][4]

### areaFactors

Area of measurement factors based on 1 square meter.

Type: [Object][4]

## feature

Wraps a GeoJSON [Geometry][5] in a GeoJSON [Feature][6].

### Parameters

*   `geometry` **[Geometry][5]** input geometry
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var geometry = {
  "type": "Point",
  "coordinates": [110, 50]
};

var feature = turf.feature(geometry);

//=feature
```

Returns **[Feature][6]** a GeoJSON Feature

## geometry

Creates a GeoJSON [Geometry][5] from a Geometry string type & coordinates.
For GeometryCollection type use `helpers.geometryCollection`

### Parameters

*   `type` **[string][8]** Geometry Type
*   `coordinates` **[Array][7]\<any>** Coordinates
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

### Examples

```javascript
var type = "Point";
var coordinates = [110, 50];
var geometry = turf.geometry(type, coordinates);
// => geometry
```

Returns **[Geometry][5]** a GeoJSON Geometry

## point

Creates a [Point][9] [Feature][6] from a Position.

### Parameters

*   `coordinates` **[Array][7]<[number][3]>** longitude, latitude position (each in decimal degrees)
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var point = turf.point([-75.343, 39.984]);

//=point
```

Returns **[Feature][6]<[Point][9]>** a Point feature

## points

Creates a [Point][9] [FeatureCollection][10] from an Array of Point coordinates.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[number][3]>>** an array of Points
*   `properties` **[Object][4]** Translate these properties to each Feature (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north]
        associated with the FeatureCollection
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the FeatureCollection

### Examples

```javascript
var points = turf.points([
  [-75, 39],
  [-80, 45],
  [-78, 50]
]);

//=points
```

Returns **[FeatureCollection][10]<[Point][9]>** Point Feature

## polygon

Creates a [Polygon][11] [Feature][6] from an Array of LinearRings.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[Array][7]<[number][3]>>>** an array of LinearRings
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var polygon = turf.polygon([[[-5, 52], [-4, 56], [-2, 51], [-7, 54], [-5, 52]]], { name: 'poly1' });

//=polygon
```

Returns **[Feature][6]<[Polygon][11]>** Polygon Feature

## polygons

Creates a [Polygon][11] [FeatureCollection][10] from an Array of Polygon coordinates.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[Array][7]<[Array][7]<[number][3]>>>>** an array of Polygon coordinates
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the FeatureCollection

### Examples

```javascript
var polygons = turf.polygons([
  [[[-5, 52], [-4, 56], [-2, 51], [-7, 54], [-5, 52]]],
  [[[-15, 42], [-14, 46], [-12, 41], [-17, 44], [-15, 42]]],
]);

//=polygons
```

Returns **[FeatureCollection][10]<[Polygon][11]>** Polygon FeatureCollection

## lineString

Creates a [LineString][12] [Feature][6] from an Array of Positions.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[number][3]>>** an array of Positions
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var linestring1 = turf.lineString([[-24, 63], [-23, 60], [-25, 65], [-20, 69]], {name: 'line 1'});
var linestring2 = turf.lineString([[-14, 43], [-13, 40], [-15, 45], [-10, 49]], {name: 'line 2'});

//=linestring1
//=linestring2
```

Returns **[Feature][6]<[LineString][12]>** LineString Feature

## lineStrings

Creates a [LineString][12] [FeatureCollection][10] from an Array of LineString coordinates.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[Array][7]<[number][3]>>>** an array of LinearRings
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north]
        associated with the FeatureCollection
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the FeatureCollection

### Examples

```javascript
var linestrings = turf.lineStrings([
  [[-24, 63], [-23, 60], [-25, 65], [-20, 69]],
  [[-14, 43], [-13, 40], [-15, 45], [-10, 49]]
]);

//=linestrings
```

Returns **[FeatureCollection][10]<[LineString][12]>** LineString FeatureCollection

## featureCollection

Takes one or more [Features][6] and creates a [FeatureCollection][10].

### Parameters

*   `features` **[Array][7]<[Feature][6]>** input features
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var locationA = turf.point([-75.343, 39.984], {name: 'Location A'});
var locationB = turf.point([-75.833, 39.284], {name: 'Location B'});
var locationC = turf.point([-75.534, 39.123], {name: 'Location C'});

var collection = turf.featureCollection([
  locationA,
  locationB,
  locationC
]);

//=collection
```

Returns **[FeatureCollection][10]** FeatureCollection of Features

## multiLineString

Creates a [Feature\<MultiLineString>][13] based on a
coordinate array. Properties can be added optionally.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[Array][7]<[number][3]>>>** an array of LineStrings
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var multiLine = turf.multiLineString([[[0,0],[10,10]]]);

//=multiLine
```

*   Throws **[Error][14]** if no coordinates are passed

Returns **[Feature][6]<[MultiLineString][15]>** a MultiLineString feature

## multiPoint

Creates a [Feature\<MultiPoint>][16] based on a
coordinate array. Properties can be added optionally.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[number][3]>>** an array of Positions
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var multiPt = turf.multiPoint([[0,0],[10,10]]);

//=multiPt
```

*   Throws **[Error][14]** if no coordinates are passed

Returns **[Feature][6]<[MultiPoint][17]>** a MultiPoint feature

## multiPolygon

Creates a [Feature\<MultiPolygon>][18] based on a
coordinate array. Properties can be added optionally.

### Parameters

*   `coordinates` **[Array][7]<[Array][7]<[Array][7]<[Array][7]<[number][3]>>>>** an array of Polygons
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var multiPoly = turf.multiPolygon([[[[0,0],[0,10],[10,10],[10,0],[0,0]]]]);

//=multiPoly
```

*   Throws **[Error][14]** if no coordinates are passed

Returns **[Feature][6]<[MultiPolygon][19]>** a multipolygon feature

## geometryCollection

Creates a [Feature\<GeometryCollection>][20] based on a
coordinate array. Properties can be added optionally.

### Parameters

*   `geometries` **[Array][7]<[Geometry][5]>** an array of GeoJSON Geometries
*   `properties` **[Object][4]** an Object of key-value pairs to add as properties (optional, default `{}`)
*   `options` **[Object][4]** Optional Parameters (optional, default `{}`)

    *   `options.bbox` **[Array][7]<[number][3]>?** Bounding Box Array \[west, south, east, north] associated with the Feature
    *   `options.id` **([string][8] | [number][3])?** Identifier associated with the Feature

### Examples

```javascript
var pt = turf.geometry("Point", [100, 0]);
var line = turf.geometry("LineString", [[101, 0], [102, 1]]);
var collection = turf.geometryCollection([pt, line]);

// => collection
```

Returns **[Feature][6]<[GeometryCollection][21]>** a GeoJSON GeometryCollection Feature

## round

Round number to precision

### Parameters

*   `num` **[number][3]** Number
*   `precision` **[number][3]** Precision (optional, default `0`)

### Examples

```javascript
turf.round(120.4321)
//=120

turf.round(120.4321, 2)
//=120.43
```

Returns **[number][3]** rounded number

## radiansToLength

Convert a distance measurement (assuming a spherical Earth) from radians to a more friendly unit.
Valid units: miles, nauticalmiles, inches, yards, meters, metres, kilometers, centimeters, feet

### Parameters

*   `radians` **[number][3]** in radians across the sphere
*   `units` **[string][8]** can be degrees, radians, miles, inches, yards, metres,
    meters, kilometres, kilometers. (optional, default `"kilometers"`)

Returns **[number][3]** distance

## lengthToRadians

Convert a distance measurement (assuming a spherical Earth) from a real-world unit into radians
Valid units: miles, nauticalmiles, inches, yards, meters, metres, kilometers, centimeters, feet

### Parameters

*   `distance` **[number][3]** in real units
*   `units` **[string][8]** can be degrees, radians, miles, inches, yards, metres,
    meters, kilometres, kilometers. (optional, default `"kilometers"`)

Returns **[number][3]** radians

## lengthToDegrees

Convert a distance measurement (assuming a spherical Earth) from a real-world unit into degrees
Valid units: miles, nauticalmiles, inches, yards, meters, metres, centimeters, kilometres, feet

### Parameters

*   `distance` **[number][3]** in real units
*   `units` **[string][8]** can be degrees, radians, miles, inches, yards, metres,
    meters, kilometres, kilometers. (optional, default `"kilometers"`)

Returns **[number][3]** degrees

## bearingToAzimuth

Converts any bearing angle from the north line direction (positive clockwise)
and returns an angle between 0-360 degrees (positive clockwise), 0 being the north line

### Parameters

*   `bearing` **[number][3]** angle, between -180 and +180 degrees

Returns **[number][3]** angle between 0 and 360 degrees

## azimuthToBearing

Converts any azimuth angle from the north line direction (positive clockwise)
and returns an angle between -180 and +180 degrees (positive clockwise), 0 being the north line

### Parameters

*   `angle` **[number][3]** between 0 and 360 degrees

Returns **[number][3]** bearing between -180 and +180 degrees

## radiansToDegrees

Converts an angle in radians to degrees

### Parameters

*   `radians` **[number][3]** angle in radians

Returns **[number][3]** degrees between 0 and 360 degrees

## degreesToRadians

Converts an angle in degrees to radians

### Parameters

*   `degrees` **[number][3]** angle between 0 and 360 degrees

Returns **[number][3]** angle in radians

## convertLength

Converts a length to the requested unit.
Valid units: miles, nauticalmiles, inches, yards, meters, metres, kilometers, centimeters, feet

### Parameters

*   `length` **[number][3]** to be converted
*   `originalUnit` **Units** of the length (optional, default `"kilometers"`)
*   `finalUnit` **Units** returned unit (optional, default `"kilometers"`)

Returns **[number][3]** the converted length

## convertArea

Converts a area to the requested unit.
Valid units: kilometers, kilometres, meters, metres, centimetres, millimeters, acres, miles, yards, feet, inches, hectares

### Parameters

*   `area` **[number][3]** to be converted
*   `originalUnit` **Units** of the distance (optional, default `"meters"`)
*   `finalUnit` **Units** returned unit (optional, default `"kilometers"`)

Returns **[number][3]** the converted area

## isNumber

isNumber

### Parameters

*   `num` **any** Number to validate

### Examples

```javascript
turf.isNumber(123)
//=true
turf.isNumber('foo')
//=false
```

Returns **[boolean][22]** true/false

## isObject

isObject

### Parameters

*   `input` **any** variable to validate

### Examples

```javascript
turf.isObject({elevation: 10})
//=true
turf.isObject('foo')
//=false
```

Returns **[boolean][22]** true/false, including false for Arrays and Functions

[1]: https://en.wikipedia.org/wiki/Earth_radius#Arithmetic_mean_radius

[2]: https://rosettacode.org/wiki/Haversine_formula#:~:text=This%20value%20is%20recommended

[3]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[4]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[5]: https://tools.ietf.org/html/rfc7946#section-3.1

[6]: https://tools.ietf.org/html/rfc7946#section-3.2

[7]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[8]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[9]: https://tools.ietf.org/html/rfc7946#section-3.1.2

[10]: https://tools.ietf.org/html/rfc7946#section-3.3

[11]: https://tools.ietf.org/html/rfc7946#section-3.1.6

[12]: https://tools.ietf.org/html/rfc7946#section-3.1.4

[13]: Feature<MultiLineString>

[14]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Error

[15]: https://tools.ietf.org/html/rfc7946#section-3.1.5

[16]: Feature<MultiPoint>

[17]: https://tools.ietf.org/html/rfc7946#section-3.1.3

[18]: Feature<MultiPolygon>

[19]: https://tools.ietf.org/html/rfc7946#section-3.1.7

[20]: Feature<GeometryCollection>

[21]: https://tools.ietf.org/html/rfc7946#section-3.1.8

[22]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean

<!-- This file is automatically generated. Please don't edit it directly. If you find an error, edit the source file of the module in question (likely index.js or index.ts), and re-run "yarn docs" from the root of the turf project. -->

---

This module is part of the [Turfjs project](https://turfjs.org/), an open source module collection dedicated to geographic algorithms. It is maintained in the [Turfjs/turf](https://github.com/Turfjs/turf) repository, where you can create PRs and issues.

### Installation

Install this single module individually:

```sh
$ npm install @turf/helpers
```

Or install the all-encompassing @turf/turf module that includes all modules as functions:

```sh
$ npm install @turf/turf
```
